Culture class

Annotations
  • @immutable

Constructors

Culture(String name, DateTimeFormat dateTimeFormat)
const

Properties

compareInfo → CompareInfo?
final
dateTimeFormat → DateTimeFormat
final
hashCode → int
The hash code for this object.
no setterinherited
isReadOnly → bool
no setter
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current ↔ Culture
getter/setter pair
invariant → Culture
final

Constants

invariantId → const String