AnnualDatePattern class

Represents a pattern for parsing and formatting AnnualDate values.

Implemented types
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
patternText → String
Gets the pattern text for this pattern, as supplied on creation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateValue → AnnualDate
Gets the value used as a template for parsing: any field values unspecified in the pattern are taken from the template.
final

Methods

appendFormat(AnnualDate value, StringBuffer builder) → StringBuffer
Formats the given value as text according to the rules of this pattern, appending to the given StringBuilder.
override
format(AnnualDate value) → String
Formats the given annual date as text according to the rules of this pattern.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → ParseResult<AnnualDate>
Parses the given text value according to the rules of this pattern.
override
toString() → String
A string representation of this object.
inherited
withCulture(Culture culture) → AnnualDatePattern
Creates a pattern for the same original pattern text as this pattern, but with the specified culture.
withTemplateValue(AnnualDate newTemplateValue) → AnnualDatePattern
Creates a pattern like this one, but with the specified template value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

iso → AnnualDatePattern
Gets an invariant annual date pattern which is compatible with the month/day part of ISO-8601. This corresponds to the text pattern "MM'-'dd".
no setter

Static Methods

createWithCulture(String patternText, Culture culture, [AnnualDate? templateValue]) → AnnualDatePattern
Creates a pattern for the given pattern text, culture, and template value.
createWithCurrentCulture(String patternText) → AnnualDatePattern
Creates a pattern for the given pattern text in the current thread's current culture.
createWithInvariantCulture(String patternText) → AnnualDatePattern
Creates a pattern for the given pattern text in the invariant culture.