LocalDatePattern class

Represents a pattern for parsing and formatting LocalDate values.

Implemented types
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
patternText → String
Gets the pattern text for this pattern, as supplied on creation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateValue → LocalDate
Gets the value used as a template for parsing: any field values unspecified in the pattern are taken from the template.
final

Methods

appendFormat(LocalDate value, StringBuffer builder) → StringBuffer
Formats the given value as text according to the rules of this pattern, appending to the given StringBuilder.
override
format(LocalDate value) → String
Formats the given local date as text according to the rules of this pattern.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → ParseResult<LocalDate>
Parses the given text value according to the rules of this pattern.
override
toString() → String
A string representation of this object.
inherited
withCalendar(CalendarSystem calendar) → LocalDatePattern
Creates a pattern like this one, but with the template value modified to use the specified calendar system.
withCulture(Culture culture) → LocalDatePattern
Creates a pattern for the same original pattern text as this pattern, but with the specified culture.
withTemplateValue(LocalDate newTemplateValue) → LocalDatePattern
Creates a pattern like this one, but with the specified template value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

iso → LocalDatePattern
Gets an invariant local date pattern which is ISO-8601 compatible. This corresponds to the text pattern "uuuu'-'MM'-'dd".
final

Static Methods

createWithCulture(String patternText, Culture culture, [LocalDate? templateValue]) → LocalDatePattern
Creates a pattern for the given pattern text, culture, and template value.
createWithCurrentCulture(String patternText) → LocalDatePattern
Creates a pattern for the given pattern text in the current thread's current culture.
createWithInvariantCulture(String patternText) → LocalDatePattern
Creates a pattern for the given pattern text in the invariant culture.