LocalTimePattern class

Represents a pattern for parsing and formatting LocalTime values.

Implemented types
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
patternText → String
Gets the pattern text for this pattern, as supplied on creation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateValue → LocalTime
Gets the value used as a template for parsing: any field values unspecified in the pattern are taken from the template.
final

Methods

appendFormat(LocalTime value, StringBuffer builder) → StringBuffer
Formats the given value as text according to the rules of this pattern, appending to the given StringBuilder.
override
format(LocalTime value) → String
Formats the given local time as text according to the rules of this pattern.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → ParseResult<LocalTime>
Parses the given text value according to the rules of this pattern.
override
toString() → String
A string representation of this object.
inherited
withCulture(Culture culture) → LocalTimePattern
Creates a pattern for the same original pattern text as this pattern, but with the specified culture.
withTemplateValue(LocalTime newTemplateValue) → LocalTimePattern
Creates a pattern like this one, but with the specified template value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

extendedIso → LocalTimePattern
Gets an invariant local time pattern which is ISO-8601 compatible, providing up to 9 decimal places. (These digits are omitted when unnecessary.) This corresponds to the text pattern "HH':'mm':'ss;FFFFFFFFF".
final

Static Methods

createWithCulture(String patternText, Culture culture, [LocalTime? templateValue]) → LocalTimePattern
Creates a pattern for the given pattern text, culture, and template value or LocalTime.midnight.
createWithCurrentCulture(String patternText) → LocalTimePattern
Creates a pattern for the given pattern text in the current thread's current culture.
createWithInvariantCulture(String patternText) → LocalTimePattern
Creates a pattern for the given pattern text in the invariant culture.