OffsetDatePattern class

Represents a pattern for parsing and formatting OffsetDate values.

Implemented types
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
patternText → String
Gets the pattern text for this pattern, as supplied on creation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateValue → OffsetDate
Gets the value used as a template for parsing: any field values unspecified in the pattern are taken from the template.
final

Methods

appendFormat(OffsetDate value, StringBuffer builder) → StringBuffer
Formats the given value as text according to the rules of this pattern, appending to the given StringBuilder.
override
format(OffsetDate value) → String
Formats the given zoned date as text according to the rules of this pattern.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → ParseResult<OffsetDate>
Parses the given text value according to the rules of this pattern.
override
toString() → String
A string representation of this object.
inherited
withCalendar(CalendarSystem calendar) → OffsetDatePattern
Creates a pattern like this one, but with the template value modified to use the specified calendar system.
withCulture(Culture culture) → OffsetDatePattern
Creates a pattern for the same original pattern text as this pattern, but with the specified culture.
withPatternText(String patternText) → OffsetDatePattern
Creates a pattern for the same original localization information as this pattern, but with the specified pattern text.
withTemplateValue(OffsetDate newTemplateValue) → OffsetDatePattern
Creates a pattern for the same original pattern text and culture as this pattern, but with the specified template value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

fullRoundtrip → OffsetDatePattern
Gets an invariant offset date pattern based on ISO-8601 including offset from UTC and calendar ID.
no setter
generalIso → OffsetDatePattern
Gets an invariant offset date pattern based on ISO-8601, including offset from UTC.
no setter

Static Methods

createWithCulture(String patternText, Culture culture, OffsetDate templateValue) → OffsetDatePattern
Creates a pattern for the given pattern text, culture, and template value.
createWithCurrentCulture(String patternText) → OffsetDatePattern
Creates a pattern for the given pattern text in the current culture, using the default template value of midnight January 1st 2000 at an offset of 0.
createWithInvariantCulture(String patternText) → OffsetDatePattern
Creates a pattern for the given pattern text in the invariant culture, using the default template value of midnight January 1st 2000 at an offset of 0.