OffsetPattern class

Represents a pattern for parsing and formatting Offset values.

Implemented types
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
patternText → String
Gets the pattern text for this pattern, as supplied on creation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendFormat(Offset value, StringBuffer builder) → StringBuffer
Formats the given value as text according to the rules of this pattern, appending to the given StringBuilder.
override
format(Offset value) → String
Formats the given offset as text according to the rules of this pattern.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → ParseResult<Offset>
Parses the given text value according to the rules of this pattern.
override
toString() → String
A string representation of this object.
inherited
withCulture(Culture culture) → OffsetPattern
Creates a pattern for the same original pattern text as this pattern, but with the specified culture.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

generalInvariant → OffsetPattern
The 'general' offset pattern (e.g. +HH, +HH:mm, +HH:mm:ss, +HH:mm:ss.fff) for the invariant culture.
final
generalInvariantWithZ → OffsetPattern
The 'general' offset pattern (e.g. +HH, +HH:mm, +HH:mm:ss, +HH:mm:ss.fff) for the invariant culture, but producing (and allowing) Z as a value for a zero offset.
final

Static Methods

createWithCulture(String patternText, Culture culture) → OffsetPattern
Creates a pattern for the given pattern text and culture.
createWithCurrentCulture(String patternText) → OffsetPattern
Creates a pattern for the given pattern text in the current thread's current culture.
createWithInvariantCulture(String patternText) → OffsetPattern
Creates a pattern for the given pattern text in the invariant culture.