TimePattern class

Represents a pattern for parsing and formatting Time values.

Implemented types
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
patternText → String
Gets the pattern text for this pattern, as supplied on creation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendFormat(Time value, StringBuffer builder) → StringBuffer
Formats the given value as text according to the rules of this pattern, appending to the given StringBuilder.
override
format(Time value) → String
Formats the given Span as text according to the rules of this pattern.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → ParseResult<Time>
Parses the given text value according to the rules of this pattern.
override
toString() → String
A string representation of this object.
inherited
withCulture(Culture culture) → TimePattern
Creates a pattern for the same original pattern text as this pattern, but with the specified culture.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

roundtrip → TimePattern
Gets the general pattern for Spans using the invariant culture, with a format string of '-D:hh:mm:ss.FFFFFFFFF'. This pattern round-trips.
no setter

Static Methods

createWithCulture(String patternText, Culture culture) → TimePattern
Creates a pattern for the given pattern text and culture.
createWithCurrentCulture(String patternText) → TimePattern
Creates a pattern for the given pattern text in the current thread's current culture.
createWithInvariantCulture(String patternText) → TimePattern
Creates a pattern for the given pattern text in the invariant culture.